local telescope = require('telescope')
local actions = require('telescope.actions')
local builtin = require('telescope.builtin')

telescope.setup {
    defaults = {
        sorting_strategy = "ascending",
        live_grep_arguments = { 'rg',
            '--hidden', '--no-ignore', '--color=never',
            '--with-filename', '--line-number',
            '--column', '--smart-case', '--no-heading',
        },
    },
    pickers = {
        live_grep = {
            mappings = {
                i = { ["<c-f>"] = actions.to_fuzzy_refine },
            },
        },
    },
}

vim.keymap.set('n', '<leader>ss', telescope.extensions.luasnip.luasnip, {})

vim.keymap.set('n', '<leader>ff', builtin.find_files, {})
vim.keymap.set('n', '<leader>ffg', builtin.git_files, {})
vim.keymap.set('n', '<leader>fg', builtin.live_grep, {})
vim.keymap.set('n', '<leader>fb', builtin.buffers, {})
vim.keymap.set('n', '<leader>fs', builtin.lsp_dynamic_workspace_symbols, {})
vim.keymap.set('n', '<leader>fsd', builtin.lsp_document_symbols, {})
vim.keymap.set('n', '<leader>fh', builtin.help_tags, {})
vim.keymap.set('n', '<leader>fd', builtin.diagnostics, {})

-- Use telescope for lsp definitions, calls and references
vim.keymap.set('n', '<leader>gd', builtin.lsp_definitions, {})
vim.keymap.set('n', '<leader>gr', builtin.lsp_references, {})
vim.keymap.set('n', '<leader>gi', builtin.lsp_implementations, {})
vim.keymap.set('n', '<leader>ci', builtin.lsp_incoming_calls, {})
vim.keymap.set('n', '<leader>co', builtin.lsp_outgoing_calls, {})
